# Check VAFs for the mutations used in Figure 2c/d.
library(vcfR)
library(ggplot2)
library(ggrepel)

ExtractAlleleCounts <- function(dat) {
  ret <- lapply(strsplit(dat, split = ":"), function(row) {
    as.numeric(unlist(strsplit(row[2], split = ",")))
  })
  ret1 <- data.frame(matrix(unlist(ret), byrow = T, ncol = 2))
  depth <- rowSums(ret1)
  ret1$VAF <- ret1[,2]/depth
  return(ret1)
}

data_path <- "../"
snv_driver_genes <- read.csv("snv_driver_genes.csv", header = T)
snv_driver_genes$LOC <- paste(snv_driver_genes$Chr, snv_driver_genes$Pos, sep=":")

sample_names<-c("S", "O", "T")
data_dirs<-matrix(c(127, 128, 130, 135, 136, 138, 143, 144, 146, 151, 152, 154, 167, 168, 170), ncol = 3, byrow = T)
normal_dirs <- c(129, 137, 145, 153, 169)
patients<-1:5
patient_id <- patients[1]

for (pid in patients)
{
  patient_name <- paste("P", pid, sep="")
  mutect2 <- list()
  gt <- list()
  allele_counts <- list()
  allele_counts.intersected <- list()
  fix.dfs <- list()
  intersections <- list()
  
  for (sample_idx in 1:2) {
    data_dir <- paste(data_path, patient_name, paste("PXXXX", data_dirs[pid,sample_idx], sep="_"), sep="/")
    mutect2[[sample_idx]] <- read.vcfR(paste(data_dir, "/06-VCF/mutect2_T", data_dirs[pid,sample_idx], "_vs_N", normal_dirs[pid], ".filtered.vcf", sep=""))
    gt[[sample_idx]] <- as.data.frame(mutect2[[sample_idx]]@gt)
    allele_counts[[sample_idx]] <- ExtractAlleleCounts(gt[[sample_idx]]$TUMOR)
    fix.dfs[[sample_idx]] <- as.data.frame(mutect2[[sample_idx]]@fix)
    allele_counts[[sample_idx]]$LOC <- paste(fix.dfs[[sample_idx]]$CHROM, fix.dfs[[sample_idx]]$POS, sep=":")
    
    #intersections[[sample_idx]] <- read.csv(paste(data_dir, "/06-VCF/snv_intersection.txt", sep=""), header = F, sep="_")
    #intersections[[sample_idx]]$LOC <- paste(intersections[[sample_idx]]$V1, intersections[[sample_idx]]$V2, sep=":")

    #allele_counts.intersected[[sample_idx]] <- allele_counts[[sample_idx]][allele_counts[[sample_idx]]$LOC %in% intersections[[sample_idx]]$LOC,]
  }

  #locs <- allele_counts.intersected[[1]]$LOC[allele_counts.intersected[[1]]$LOC %in% allele_counts.intersected[[2]]$LOC]
  locs <- intersect(allele_counts[[1]]$LOC, allele_counts[[2]]$LOC)
  allele_counts.intersected1 <- subset(allele_counts[[1]], LOC %in% locs)
  allele_counts.intersected2 <- subset(allele_counts[[2]], LOC %in% locs)
  print(paste(length(locs), 
              dim(allele_counts[[1]])[1] - dim(allele_counts.intersected1)[1],
              dim(allele_counts[[2]])[1] - dim(allele_counts.intersected2)[1]))

  print(paste("Aligned?", as.logical(mean(allele_counts.intersected1$LOC == allele_counts.intersected2$LOC))))
  plot.df <- data.frame("WTC"=allele_counts.intersected1$VAF, "TSC"=allele_counts.intersected2$VAF, LOC = allele_counts.intersected1$LOC, Patient = patient_name)
  corr <- cor(plot.df$WTC, plot.df$TSC) 
  pl <- ggplot(plot.df, aes(x = WTC, y = TSC)) + geom_point() + geom_abline(slope = 1, intercept = 0, col='#D55E00') + theme_classic()
  pl <- pl + annotate("text", x = 0.85, y = 0, label = paste("Pearson Correlation:", signif(corr, 3))) + xlim(c(0, 1)) + ylim(c(0, 1))
  pl <- pl + ggtitle("VAF of shared mutations across TSC and WTC.")
  sub_dat <- subset(plot.df, LOC %in% snv_driver_genes$LOC & Patient %in% snv_driver_genes$Patient)
  sub_dat <- dplyr::left_join(sub_dat, snv_driver_genes, by = c("Patient", "LOC"))
  sub_dat <- sub_dat[!duplicated(sub_dat$LOC),]
  #pl <- pl + geom_label_repel(data = sub_dat, aes(x = WTC, y = TSC, label = Gene, col = Effect), box.padding = 0.5, max.overlaps = Inf, show.legend = F)
  #pl <- pl + geom_point(data = sub_dat, aes(x = WTC, y = TSC, col = Effect))
  pl <- pl + geom_point(data = sub_dat, aes(x = WTC, y = TSC), col = "#0072B2")
  pl <- pl + geom_label_repel(data = sub_dat, aes(x = WTC, y = TSC, label = Gene), col = "#0072B2", box.padding = 0.5, max.overlaps = Inf, show.legend = F)
  ggsave(pl, filename = paste(patient_name, "VAF_plot.pdf", sep=""))
}


