rm(list=ls())
library(biomaRt)
library(ggplot2)
library(dplyr)
source("helper_functions.R")

ensembl=useMart("ensembl")
listDatasets(ensembl)
ensembl <- useDataset("hsapiens_gene_ensembl",mart=ensembl)
listDatasets(ensembl)

ensembl <- useMart("ensembl",dataset="hsapiens_gene_ensembl")
filters <- listFilters(ensembl)
filters[1:5,]

attributes <- listAttributes(ensembl)
attributes[1:10,]

gene_list<-read.csv("BC_driver_genes.csv", header=F)
genes<-getBM(attributes = c("hgnc_symbol","chromosome_name", "start_position", "end_position"),
             filters = "hgnc_symbol", values = gene_list$V1,mart = ensembl)
dim(genes)

chrs<-paste(1:22, "", sep="")
chrs<-c(chrs, "X", "Y", "MT")
genes<-genes[genes$chromosome_name %in% chrs,]

# read and plot the data
patient_ids <- paste("P", seq(1,5), sep="")
all_dat<-list()
plots<-list()
dat<-data.frame()
for (i in 1:length(patient_ids))
{
  patient_id = patient_ids[i]
  patient_dir <- paste("../", patient_id, sep="")
  dirs <- sort(list.dirs(path = patient_dir, full.names = FALSE, recursive = FALSE), decreasing = F)
  time0<-get_data(patient_dir, dirs[1], "S", genes, patient_id)
  ot<-get_data(patient_dir, dirs[2], "W", genes, patient_id)
  tumor<-get_data(patient_dir, dirs[3], "T", genes, patient_id)
  df<-rbind(time0, ot, tumor)
  df<-subset(df, ratio > 0.0)
  df$log2_ratio<-log2(df$ratio)
  ret <- df %>% group_by(patient_id, gene, type) %>% summarise(log2_ratio = mean(log2_ratio))
  temp<-as.data.frame(ret)
  all_dat[[i]]<-temp
  #plots[[i]]<-plot_avg_data(ret, T, paste(patient_dir, paste(patient_id, ".pdf", sep=""), sep="/"))
  dat <- rbind(dat, temp)
}
dim(dat)
write.table(dat, file = "cna_dat.csv", sep=",", col.names = T, row.names = F, quote = F)

font_size <- 4
base_size <- 8
dat$type<-factor(dat$type, levels=c("T", "S", "W"))
dat2 <- subset(dat, dat$type == "S" | dat$type == "W")
p <- ggplot(dat2) + geom_tile(aes(x = gene, y = type, fill = log2_ratio, width=1, height=1), colour = "white")
p <- p + theme_bw()
#p <- p + facet_grid(rows = vars(patient_id), switch = "y", margins = FALSE)
p <- p + facet_wrap(vars(patient_id), nrow = 5, ncol = 1, strip.position = "left")
p <- p + theme(axis.title = element_blank())
p <- p + theme(strip.text.y = element_text(angle = 180), strip.placement = "outside", strip.background.y = element_blank())
p <- p + theme(axis.text.x = element_text(angle = 90, hjust = 1, vjust = 0.5, size=font_size))
p <- p + theme(axis.ticks = element_blank(), axis.text.x = element_text(size = base_size, colour = "black"))
p <- p + theme(panel.spacing.y = unit(0, "lines"))
p <- p + theme(legend.title = element_blank())
p <- p + coord_fixed()
p <- p + scale_fill_gradient2(low="blue", mid="white", high="red", 
                              midpoint=0, limits=range(dat$log2_ratio))
p
ggsave(filename = "CNA.pdf", p, width = 11, height = 2, units = "in")


# patient 2 S and W samples look eerily similar!
temp<-subset(dat2, dat2$patient_id == "P2")
names(temp)
temp1<-subset(temp, temp$type == "S")
temp2<-subset(temp, temp$type == "W")
diff<-temp1$log2_ratio - temp$log2_ratio
plot(density(diff))
var(diff)
p <- ggplot(temp, aes(gene, log2_ratio, col=type)) + geom_point()
p <- p + theme(axis.text.x = element_text(angle = 90, hjust = 1, vjust = 0.5, size=6))
p
ggsave(filename = "cna_P2.pdf", p, width=10, height = 4, units="in")
