get_data<-function(patient_dir, sample_name, sample_type, gene_list, patient_id)
{
  sample_file <- paste(sample_name, ".clean.dedup.bam_ratio.txt", sep="")
  data_path <- paste(patient_dir, sample_name, "05-CNA", sample_file, sep="/")

  cnv<-read.table(data_path, header = T, sep="\t")
  dat<-data.frame()
  for (i in 1:dim(gene_list)[1])
  {
    chr <- gene_list[i,"chromosome_name"]
    start_pos <- gene_list[i,"start_position"]
    end_pos <- gene_list[i,"end_position"]
    cnv_temp <- subset(cnv, paste(cnv$Chromosome,"", sep="") == chr)
    cnv_temp1 <- subset(cnv_temp, start_pos - 1000 <= cnv_temp$Start)
    cnv_temp2 <- subset(cnv_temp1, cnv_temp1$Start < end_pos)
    #  dim(cnv_temp2)
    n<-dim(cnv_temp2)[1]
    print("===")
    print(c(cnv_temp2$Start[1], cnv_temp2$Start[n]))
    print(c(start_pos, end_pos, end_pos-start_pos))
    print("===")
    x<-data.frame(gene=gene_list[i,"hgnc_symbol"], ratio=cnv_temp2$Ratio)
    dat<-rbind(dat, x)
  }
  #dat<-dat[!is.na(dat$log2_ratio),]
  #dat<-dat[dat$log2_ratio != -Inf,]

  dat$type <- sample_type
  dat$patient_id <- patient_id

  return(dat)
}

plot_data<-function(dat1, dat2, save_figure=T, save_path="fig.pdf")
{
  font_size = 4
  df<-rbind(dat1, dat2)
  p <- ggplot(df, aes(gene, type)) + geom_tile(aes(fill = log2_ratio), colour = "white")
  p <- p + theme_bw()
  p <- p + theme(text = element_text(size=font_size), 
                 axis.text.x = element_text(angle = 90, hjust = 1))
  p <- p + scale_fill_gradient2(low="blue", mid="white", high="red", 
                                midpoint=0, limits=range(df$log2_ratio))
  if (save_figure) {
    ggsave(filename = save_path, plot = p)
  } else {
    return(p) # return the figure handle
  }
}

plot_avg_data<-function(df, save_figure=F, save_path="fig.pdf")
{
  font_size = 4
  p <- ggplot(df, aes(gene, type)) + geom_tile(aes(fill = log2_ratio, width=1, height=1), colour = "white")
  p <- p + theme_bw()
  p <- p + theme(axis.text.x = element_text(angle = 90, hjust = 1, size=font_size))
  p <- p + scale_fill_gradient2(low="blue", mid="white", high="red", 
                                midpoint=0, limits=range(df$log2_ratio))
  if (save_figure) {
    ggsave(filename = save_path, plot = p)
  }
  return(p) # return the figure handle
}

# input: I1, I2 are both IRanges object
overlaps<-function(I1, I2)
{
  # first sort the two ranges so that I1@start < I2@start
  if (I1@start > I2@start) {
    I_temp <- I1
    I1 <- I2
    I2 <- I_temp
  }
  # two ranges I1, I2 overlap if I1@end > I2@start and vice versa
  if ((I1@start + I1@width - 1) >= I2@start)
    return(TRUE)
  
  return(FALSE)
}

# target_range: a vector with two elements start and end
# candidate_ranges: a matrix with n > 1 rows and 2 columns (coln1: start pos, coln2: end pos)
overlaps2<-function(target_range, candidate_ranges)
{
  count1 <- (target_range[1] <= candidate_ranges[,1]) & (target_range[2] >= candidate_ranges[,1])
  count2 <- (candidate_ranges[,1] <= target_range[1]) & (candidate_ranges[,2] >= target_range[1])
  return(count1 | count2)
}

# test overlaps
#I1<-IRanges(start = 10, end = 20)
#I2<-IRanges(start = 5, end = 9)
#overlaps(I1, I2)
